@@ -21,7 +21,7 @@ def main(args):
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser()
-    parser.add_argument('--img_path', type=str, default='data/test_face_alignment.jpg')
+    parser.add_argument('--img_path', type=str, default='inference/data/test_face_alignment.jpg')
     parser.add_argument('--save_path', type=str, default='result_face_alignment.png')
     parser.add_argument('--model_name', type=str, default='awing_fan')
     parser.add_argument('--half', action='store_true')
